From 63e133d5c1a1d223014e3e0052bff8898418f8b7 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Rodrigo=20Ram=C3=ADrez=20Norambuena?= <a@rodrigoramirez.com>
Date: Mon, 9 Sep 2019 16:14:54 -0300
Subject: [PATCH] Refactor: Remove extra else in __str__ for Quote:

Add a testing init for enviroment to build tests againt model. This
add a runner called runtests.py.

In this runner run the varnish_local.sql to help the testing model.

diff --git a/pgweb/quotes/models.py b/pgweb/quotes/models.py
index ec7b1ed..1573d24 100644
--- a/pgweb/quotes/models.py
+++ b/pgweb/quotes/models.py
@@ -15,5 +15,4 @@ class Quote(models.Model):
     def __str__(self):
         if len(self.quote) > 75:
             return "%s..." % self.quote[:75]
-        else:
-            return self.quote
+        return self.quote
diff --git a/pgweb/quotes/tests/__init__.py b/pgweb/quotes/tests/__init__.py
new file mode 100644
index 0000000..e69de29
diff --git a/pgweb/quotes/tests/test_quotes.py b/pgweb/quotes/tests/test_quotes.py
new file mode 100644
index 0000000..320dd26
--- /dev/null
+++ b/pgweb/quotes/tests/test_quotes.py
@@ -0,0 +1,16 @@
+from django.test import TestCase
+from django.db.models import signals
+from pgweb.quotes.models import Quote
+from pgweb.util.signals import my_post_save_handler
+
+class QuoteTestCase(TestCase):
+
+    def test_str_max_long(self):
+        text = "Quorum commit for synchronous replication in PostgreSQL 10" \
+            " gives more options to extend our ability to promote database " \
+            "infrastructure with nearly zero downtime from the application perspective." \
+            "This allows us to continuously deploy and update our database " \
+            "infrastructure without incurring long maintenance windows."
+
+        q = Quote.objects.create(quote=text, link="https://www.postgresql.org/")
+        self.assertEqual(str(q), "Quorum commit for synchronous replication in PostgreSQL 10 gives more optio...")
diff --git a/pgweb/settings.py b/pgweb/settings.py
index 540a099..4e17311 100644
--- a/pgweb/settings.py
+++ b/pgweb/settings.py
@@ -1,4 +1,9 @@
 # Django settings for pgweb project.
+import sys
+import os
+
+# Root full path for project
+BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
 DEBUG = False
 
@@ -161,5 +166,9 @@ FRONTEND_SMTP_RELAY = "magus.postgresql.org"                # Where to relay use
 OAUTH = {}                                                  # OAuth providers and keys
 PGDG_ORG_ID = -1                                            # id of the PGDG organisation entry
 
+
+# Testing
+TESTING = len(sys.argv) > 1 and sys.argv[1] == 'test'
+
 # Load local settings overrides
 from .settings_local import *
diff --git a/runtests.py b/runtests.py
new file mode 100755
index 0000000..9c42638
--- /dev/null
+++ b/runtests.py
@@ -0,0 +1,33 @@
+#!/usr/bin/env python
+import os
+import sys
+
+import django
+from django.conf import settings
+from django.test.utils import get_runner
+from django.db import connection
+from django.db.models.signals import pre_migrate
+from django.dispatch import receiver
+
+@receiver(pre_migrate)
+def my_pre_migrate(sender, **kwargs):
+    load_local_varnish_function()
+
+def load_local_varnish_function():
+    sql_file = os.path.join(settings.BASE_DIR, 'sql', 'varnish_local.sql')
+    with open(sql_file, 'rb') as query:
+        connection.cursor().execute(query.read())
+
+
+def tests_to_run():
+    return ['pgweb.quotes']
+
+if __name__ == "__main__":
+    # we'll need define a custom setting for test enviroment
+    os.environ['DJANGO_SETTINGS_MODULE'] = 'pgweb.settings'
+    django.setup()
+    TestRunner = get_runner(settings)
+    test_runner = TestRunner()
+    failures = test_runner.run_tests(tests_to_run())
+    load_local_varnish_function()
+    sys.exit(bool(failures))
-- 
2.11.0

